EXPORTS
	??1CBatchCommand@UndoSystem@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall UndoSystem::CBatchCommand::~CBatchCommand(void)
	?AddInverseToLast@CSingleCommand@UndoSystem@@UBEXAAV12@@Z @ 2 NONAME ; public: virtual void __thiscall UndoSystem::CSingleCommand::AddInverseToLast(class UndoSystem::CSingleCommand &)const 
	?AllowNotUndoableL@MNotUndoableGatekeeper@UndoSystem@@UAEHH@Z @ 3 NONAME ; public: virtual int __thiscall UndoSystem::MNotUndoableGatekeeper::AllowNotUndoableL(int)
	?Batch@CBatchCommand@UndoSystem@@UAEPAV12@XZ @ 4 NONAME ; public: virtual class UndoSystem::CBatchCommand * __thiscall UndoSystem::CBatchCommand::Batch(void)
	?Batch@CSingleCommand@UndoSystem@@UAEPAVCBatchCommand@2@XZ @ 5 NONAME ; public: virtual class UndoSystem::CBatchCommand * __thiscall UndoSystem::CSingleCommand::Batch(void)
	?BeginBatchLC@CCommandManager@UndoSystem@@QAEXXZ @ 6 NONAME ; public: void __thiscall UndoSystem::CCommandManager::BeginBatchLC(void)
	?CanRedo@CCommandManager@UndoSystem@@QBEHXZ @ 7 NONAME ; public: int __thiscall UndoSystem::CCommandManager::CanRedo(void)const 
	?CanRedo@CEditorWithUndo@@QBEHXZ @ 8 NONAME ; public: int __thiscall CEditorWithUndo::CanRedo(void)const 
	?CanUndo@CCommandManager@UndoSystem@@QBEHXZ @ 9 NONAME ; public: int __thiscall UndoSystem::CCommandManager::CanUndo(void)const 
	?CanUndo@CEditorWithUndo@@QBEHXZ @ 10 NONAME ; public: int __thiscall CEditorWithUndo::CanUndo(void)const 
	?CreateInverseL@CSingleCommand@UndoSystem@@UBEPAVCCommand@2@XZ @ 11 NONAME ; public: virtual class UndoSystem::CCommand * __thiscall UndoSystem::CSingleCommand::CreateInverseL(void)const 
	?ExecuteL@CCommandManager@UndoSystem@@QAEHABVCSingleCommand@2@@Z @ 12 NONAME ; public: int __thiscall UndoSystem::CCommandManager::ExecuteL(class UndoSystem::CSingleCommand const &)
	?FamilyUid@CSingleCommand@UndoSystem@@UBE?AVTUid@@XZ @ 13 NONAME ; public: virtual class TUid  __thiscall UndoSystem::CSingleCommand::FamilyUid(void)const 
	?NewL@CBatchCommand@UndoSystem@@SAPAV12@XZ @ 14 NONAME ; public: static class UndoSystem::CBatchCommand * __cdecl UndoSystem::CBatchCommand::NewL(void)
	?NewL@CCommandManager@UndoSystem@@SAPAV12@XZ @ 15 NONAME ; public: static class UndoSystem::CCommandManager * __cdecl UndoSystem::CCommandManager::NewL(void)
	?NewL@CEditorPlainTextWithUndo@@SAPAV1@AAVMUnifiedEditor@@PAVCCommandManager@UndoSystem@@@Z @ 16 NONAME ; public: static class CEditorPlainTextWithUndo * __cdecl CEditorPlainTextWithUndo::NewL(class MUnifiedEditor &,class UndoSystem::CCommandManager *)
	?NewL@CEditorWithUndo@@SAPAV1@AAVMUnifiedEditor@@@Z @ 17 NONAME ; public: static class CEditorWithUndo * __cdecl CEditorWithUndo::NewL(class MUnifiedEditor &)
	?NewL@CEditorWithUndo@@SAPAV1@AAVMUnifiedEditor@@PAVCCommandManager@UndoSystem@@@Z @ 18 NONAME ; public: static class CEditorWithUndo * __cdecl CEditorWithUndo::NewL(class MUnifiedEditor &,class UndoSystem::CCommandManager *)
	?NewLC@CBatchCommand@UndoSystem@@SAPAV12@XZ @ 19 NONAME ; public: static class UndoSystem::CBatchCommand * __cdecl UndoSystem::CBatchCommand::NewLC(void)
	?NewReference@CCommandManager@UndoSystem@@QAEXXZ @ 20 NONAME ; public: void __thiscall UndoSystem::CCommandManager::NewReference(void)
	?Pop@CBatchCommand@UndoSystem@@QAEPAVCSingleCommand@2@XZ @ 21 NONAME ; public: class UndoSystem::CSingleCommand * __thiscall UndoSystem::CBatchCommand::Pop(void)
	?PrepareToAddInverseToLastL@CSingleCommand@UndoSystem@@UBEHAAV12@@Z @ 22 NONAME ; public: virtual int __thiscall UndoSystem::CSingleCommand::PrepareToAddInverseToLastL(class UndoSystem::CSingleCommand &)const 
	?PrepareToPushL@CBatchCommand@UndoSystem@@QAEXPAVCCommand@2@@Z @ 23 NONAME ; public: void __thiscall UndoSystem::CBatchCommand::PrepareToPushL(class UndoSystem::CCommand *)
	?Push@CBatchCommand@UndoSystem@@QAEXPAVCCommand@2@@Z @ 24 NONAME ; public: void __thiscall UndoSystem::CBatchCommand::Push(class UndoSystem::CCommand *)
	?PushL@CBatchCommand@UndoSystem@@QAEXPAVCCommand@2@@Z @ 25 NONAME ; public: void __thiscall UndoSystem::CBatchCommand::PushL(class UndoSystem::CCommand *)
	?RedoL@CCommandManager@UndoSystem@@QAEXXZ @ 26 NONAME ; public: void __thiscall UndoSystem::CCommandManager::RedoL(void)
	?RedoL@CEditorWithUndo@@QAEXXZ @ 27 NONAME ; public: void __thiscall CEditorWithUndo::RedoL(void)
	?Release@CCommandManager@UndoSystem@@QAEXXZ @ 28 NONAME ; public: void __thiscall UndoSystem::CCommandManager::Release(void)
	?ResetUndo@CCommandManager@UndoSystem@@QAEXXZ @ 29 NONAME ; public: void __thiscall UndoSystem::CCommandManager::ResetUndo(void)
	?ResetUndo@CEditorWithUndo@@QAEXXZ @ 30 NONAME ; public: void __thiscall CEditorWithUndo::ResetUndo(void)
	?RetryOutOfMemoryL@MNotUndoableGatekeeper@UndoSystem@@UAEHH@Z @ 31 NONAME ; public: virtual int __thiscall UndoSystem::MNotUndoableGatekeeper::RetryOutOfMemoryL(int)
	?SetGatekeeper@CCommandManager@UndoSystem@@QAEPAVMNotUndoableGatekeeper@2@PAV32@@Z @ 32 NONAME ; public: class UndoSystem::MNotUndoableGatekeeper * __thiscall UndoSystem::CCommandManager::SetGatekeeper(class UndoSystem::MNotUndoableGatekeeper *)
	?SetGatekeeper@CEditorWithUndo@@QAEPAVMNotUndoableGatekeeper@UndoSystem@@PAV23@@Z @ 33 NONAME ; public: class UndoSystem::MNotUndoableGatekeeper * __thiscall CEditorWithUndo::SetGatekeeper(class UndoSystem::MNotUndoableGatekeeper *)
	?SetMaxItems@CCommandManager@UndoSystem@@QAEXH@Z @ 34 NONAME ; public: void __thiscall UndoSystem::CCommandManager::SetMaxItems(int)
	?SetMaxItems@CEditorWithUndo@@QAEXH@Z @ 35 NONAME ; public: void __thiscall CEditorWithUndo::SetMaxItems(int)
	?Single@CBatchCommand@UndoSystem@@UAEPAVCSingleCommand@2@XZ @ 36 NONAME ; public: virtual class UndoSystem::CSingleCommand * __thiscall UndoSystem::CBatchCommand::Single(void)
	?Single@CSingleCommand@UndoSystem@@UAEPAV12@XZ @ 37 NONAME ; public: virtual class UndoSystem::CSingleCommand * __thiscall UndoSystem::CSingleCommand::Single(void)
	?Top@CBatchCommand@UndoSystem@@QBEPAVCSingleCommand@2@XZ @ 38 NONAME ; public: class UndoSystem::CSingleCommand * __thiscall UndoSystem::CBatchCommand::Top(void)const 
	?UndoL@CCommandManager@UndoSystem@@QAEXXZ @ 39 NONAME ; public: void __thiscall UndoSystem::CCommandManager::UndoL(void)
	?UndoL@CEditorWithUndo@@QAEXXZ @ 40 NONAME ; public: void __thiscall CEditorWithUndo::UndoL(void)
	?IsAtBookmark@CCommandManager@UndoSystem@@QBEHXZ @ 41 NONAME ; public: int __thiscall UndoSystem::CCommandManager::IsAtBookmark(void)const 
	?SetBookmark@CCommandManager@UndoSystem@@QAEXXZ @ 42 NONAME ; public: void __thiscall UndoSystem::CCommandManager::SetBookmark(void)

